import { CloseOutlined } from '@ant-design/icons';
import { Button, Flex, Image, Modal, Space, theme, Typography } from 'antd';
import React, { useState } from 'react';
import style from './index.less';

interface Props {
  materialExampleType: string;
  claimJson: string;
  items?: string[];
  resourceUrl?: string;
}
const Material: React.FC<Props> = ({ materialExampleType, items = [], resourceUrl, claimJson }) => {
  /******************************/
  const [visible, setVisible] = useState<boolean>(false);
  const { size, extent } = JSON.parse(claimJson);
  const { useToken } = theme;
  const { token } = useToken();
  /******************************/

  return (
    <>
      <Flex vertical={true}>
        <Typography.Title level={5}>素材制作要求</Typography.Title>
        <Typography.Text>
          素材尺寸：{size?.[0]} * {size?.[1]}
        </Typography.Text>
        <Typography.Text>
          素材大小：
          <Space direction="vertical" size={0}>
            <Typography.Text>
              {extent?.[0]}MB ~ {extent?.[1]}MB
            </Typography.Text>
            <Typography.Text>
              {extent?.[0] ? extent?.[0] * 1024 : extent?.[0]}KB ~{' '}
              {extent?.[1] ? extent?.[1] * 1024 : extent?.[1]}KB
            </Typography.Text>
          </Space>
        </Typography.Text>
      </Flex>

      <Space>
        {items.length > 0 && (
          <>
            {materialExampleType === 'MATERIAL_TYPE_VIDEO' && visible ? (
              <Modal
                open={visible}
                styles={{
                  body: {
                    backgroundColor: 'rgba(0,0,0,0.8)',
                    overflow: 'hidden',
                    borderRadius: token.borderRadius,
                    padding: '20px 24px',
                  },
                }}
                footer={null}
                closeIcon={<CloseOutlined style={{ color: token.colorPrimary }} />}
                onCancel={(e) => {
                  e.stopPropagation();
                  setVisible(false);
                }}
                className="playVideo"
                destroyOnClose={true}
              >
                {visible && (
                  <video
                    className={style.video}
                    style={{ borderRadius: token.borderRadius }}
                    src={items[0]}
                    autoPlay
                    controls
                    controlsList="nodownload"
                  >
                    您的浏览器不支持 video 标签。
                  </video>
                )}
              </Modal>
            ) : (
              <Image.PreviewGroup
                items={items}
                preview={{
                  visible: visible,
                  onVisibleChange: (value) => {
                    setVisible(value);
                  },
                }}
              />
            )}

            <Button type="link" style={{ padding: 0 }} onClick={() => setVisible(true)}>
              素材示例
            </Button>
          </>
        )}
        {resourceUrl && (
          <Button
            type="link"
            style={{ paddingLeft: 0, paddingRight: 0 }}
            href={resourceUrl}
            download="资源包下载"
          >
            资源包下载
          </Button>
        )}
      </Space>
    </>
  );
};

export default React.memo(Material);
