import LookVideo from '@/components/LookVideo';
import { Button, Flex, Typography } from 'antd';
import { ColumnsType } from 'antd/es/table';

const Columns = (download: (url: string, userMaterialId: number) => void): ColumnsType<any> => {
  let arr: ColumnsType<any> = [
    {
      title: '素材预览',
      dataIndex: 'link',
      key: 'link',
      align: 'center',
      width: 120,
      fixed: 'left',
      render: (a, b) => {
        return <LookVideo urlList={[a]} />;
      },
    },
    {
      title: '上传时间',
      dataIndex: 'materialCreateTime',
      key: 'materialCreateTime',
      align: 'center',
      width: 120,
    },
    {
      title: '上传任务名称',
      dataIndex: 'taskName',
      key: 'taskName',
      align: 'center',
      width: 150,
      render(value) {
        return (
          <Typography.Paragraph style={{ marginBottom: 0 }} ellipsis={{ rows: 3 }}>
            {value}
          </Typography.Paragraph>
        );
      },
    },
    {
      title: '上传任务ID',
      dataIndex: 'taskId',
      key: 'taskId',
      align: 'center',
      width: 90,
    },
    {
      title: '素材规格',
      dataIndex: 'materialClaimJson',
      key: 'materialClaimJson',
      width: 150,
      render(value) {
        if (value) {
          const { size, extent } = JSON.parse(value);
          return (
            <Flex vertical={true}>
              <Typography.Text>
                素材尺寸：{size?.[0]} * {size?.[1]}
              </Typography.Text>
              <Typography.Text>
                素材大小：{extent?.[0]}MB ~ {extent?.[1]}MB
              </Typography.Text>
            </Flex>
          );
        } else {
          return '--';
        }
      },
    },
    {
      title: '下载时间',
      dataIndex: 'createTime',
      key: 'createTime',
      align: 'center',
      width: 120,
    },
    {
      title: '操作',
      dataIndex: 'cz',
      key: 'cz',
      align: 'center',
      width: 75,
      fixed: 'right',
      render(value, record) {
        return (
          <Button type="link" onClick={() => download(record.link, record.materialId)}>
            再次下载
          </Button>
        );
      },
    },
  ];

  return arr;
};

export default Columns;
