import Material from '@/components/Material';
import { getTaskMemberListApi } from '@/services/task-api/task';
import {
  MaterialSourceEnum,
  MaterialTypeEle,
  StatusEnum,
  TaskStatusEle,
  TaskTypeEle,
  TaskTypeEnum,
} from '@/utils/constEnum';
import { AlertOutlined, SearchOutlined } from '@ant-design/icons';
import { PageContainer } from '@ant-design/pro-components';
import { useRequest, useSize } from 'ahooks';
import {
  Affix,
  Alert,
  Avatar,
  Card,
  Flex,
  Input,
  List,
  Select,
  Space,
  Tag,
  theme,
  Tooltip,
  Typography,
} from 'antd';
import { useEffect, useRef, useState } from 'react';
import SubmitTask from './submitTask';

/**
 * 任务中心
 * @returns
 */
const Task: React.FC = () => {
  /***********************************/
  const { useToken } = theme;
  const ref = useRef(null);
  const size = useSize(ref);
  const { token } = useToken();
  const [queryForm, setQueryForm] = useState<TASKAPI.TaskMemberList>({ pageNum: 1, pageSize: 10 });
  const getTaskMemberList = useRequest(getTaskMemberListApi, { manual: true }); //添加请求
  /***********************************/

  useEffect(() => {
    let data = JSON.parse(JSON.stringify(queryForm));
    if (data?.taskType === 'taskType') {
      delete data.taskType;
    }
    if (data?.status === 'status') {
      delete data.status;
    }
    getTaskMemberList.run(data);
  }, [queryForm]);

  return (
    <PageContainer>
      <Card
        style={{
          borderRadius: 8,
        }}
        bodyStyle={{
          paddingTop: 0,
          paddingLeft: 0,
          paddingRight: 0,
        }}
        ref={ref}
      >
        <Space direction="vertical" style={{ width: '100%' }} size={0}>
          <Affix offsetTop={56}>
            <div
              style={{
                backgroundColor: token.colorBgBase,
                padding: token.paddingContentHorizontalLG,
                paddingBottom: 5,
                borderRadius: 8,
                borderBottom: `1px solid ${token.colorBorderSecondary}`,
              }}
            >
              <Space direction="vertical" style={{ width: '100%' }}>
                <Space wrap>
                  <Input
                    prefix={<SearchOutlined />}
                    value={queryForm?.name}
                    onChange={(e) =>
                      setQueryForm({ ...queryForm, name: e.target.value, pageNum: 1 })
                    }
                    placeholder="搜索你感兴趣的悬赏任务"
                    style={{ width: 300 }}
                  />
                  <Alert
                    style={{ padding: `4px 12px` }}
                    type="warning"
                    showIcon
                    icon={<AlertOutlined />}
                    message="官方公告：点击任务内的素材上传按钮完成任务，即有机会获取丰厚的奖励！"
                  />
                </Space>
                <Space>
                  <Select
                    className="drawSelect"
                    style={{ width: 100, padding: 0 }}
                    bordered={false}
                    allowClear
                    placeholder="任务分类"
                    value={queryForm?.taskType}
                    onChange={(e) => setQueryForm({ ...queryForm, taskType: e, pageNum: 1 })}
                    options={Object.keys(TaskTypeEnum).map((key) => ({
                      value: key,
                      label: (TaskTypeEnum as any)[key],
                    }))}
                  />
                  <Select
                    className="drawSelect"
                    style={{ width: 100, padding: 0 }}
                    bordered={false}
                    allowClear
                    value={queryForm?.status}
                    placeholder="任务状态"
                    onChange={(e) => setQueryForm({ ...queryForm, status: e, pageNum: 1 })}
                    options={Object.keys(StatusEnum).map((key) => ({
                      value: key,
                      label: (StatusEnum as any)[key],
                    }))}
                  />
                </Space>
              </Space>
            </div>
          </Affix>

          <List
            itemLayout="vertical"
            size="large"
            dataSource={getTaskMemberList.data?.data?.records}
            loading={getTaskMemberList.loading}
            pagination={{
              onChange: (page) => {
                console.log(page);
                setQueryForm({ ...queryForm, pageNum: page });
              },
              current: queryForm.pageNum,
              pageSize: queryForm.pageSize,
              total: getTaskMemberList?.data?.data?.total,
              showTotal: (total) => <Tag color="cyan">总共{total}数据</Tag>,
            }}
            renderItem={(item: any, index) => (
              <List.Item
                key={item.title}
                extra={
                  <Flex gap={20} style={{ height: '100%' }}>
                    <Flex
                      style={{ width: size?.width ? `${size?.width / 2 - 265}px` : 300 }}
                      vertical={true}
                      align="flex-start"
                      justify="space-between"
                    >
                      <Material
                        materialExampleType={item?.materialExampleType}
                        items={item?.materialExample?.split(',')}
                        resourceUrl={item.materialResource}
                        claimJson={item.materialClaimJson}
                      />
                    </Flex>
                    <Flex
                      style={{ width: 165, height: '100%' }}
                      gap={10}
                      vertical={true}
                      align="flex-end"
                      justify="space-between"
                    >
                      {TaskStatusEle[item.status]}
                      {item.status === 'STATUS_NORMAL' && (
                        <SubmitTask
                          taskId={item.id}
                          name={item.name}
                          materialType={item.materialType}
                          materialClaimJson={item.materialClaimJson}
                          onChange={() => getTaskMemberList.refresh()}
                        />
                      )}
                      <Tag color="error" style={{ marginInlineEnd: 0 }}>
                        结算：
                        {item.checkoutType === 'CHECKOUT_TYPE_SCALE'
                          ? `总消耗 ${item.checkout * 100}%`
                          : `${item.checkout}元（审核合格）`}
                      </Tag>
                    </Flex>
                  </Flex>
                }
                actions={[
                  <Tooltip title="发布时间" key={1}>
                    <span>{item.createTime}</span>
                  </Tooltip>,
                  <Tooltip title="任务分类" key={2}>
                    {TaskTypeEle[item.taskType]}
                  </Tooltip>,
                  <Tooltip title="素材类型" key={3}>
                    {MaterialTypeEle[item.materialType]}
                  </Tooltip>,
                  <Tooltip title="素材来源要求" key={4}>
                    <Tag style={{ marginInlineEnd: 0 }}>
                      {(MaterialSourceEnum as any)[item.materialSource]}
                    </Tag>
                  </Tooltip>,
                ]}
              >
                <List.Item.Meta
                  avatar={
                    <Avatar
                      src={
                        item.avatar ||
                        `https://xsgames.co/randomusers/avatar.php?g=pixel&key=${index}`
                      }
                      style={{ backgroundColor: '#87d068' }}
                    />
                  }
                  title={
                    <Space size={20}>
                      <Typography.Title level={5} style={{ marginBottom: 0 }}>
                        {item.name}_任务ID：{item.id}
                      </Typography.Title>
                      {!!item.urgency && (
                        <Space size={4}>
                          <span style={{ color: 'red' }}>置顶</span>🆙
                        </Space>
                      )}
                    </Space>
                  }
                  description={
                    <Space direction="vertical" style={{ width: '100%' }} size={0}>
                      {/* 有效时间 */}
                      <Typography.Text type="secondary" ellipsis>
                        任务有效时间：{item.startTime}~{item.endTime ? item.endTime : '长期有效'}
                      </Typography.Text>
                      {/* 任务描述 */}
                      {item.remark && (
                        <Typography.Text type="secondary" ellipsis={{ tooltip: true }}>
                          {item.remark}
                        </Typography.Text>
                      )}
                    </Space>
                  }
                />
                <Typography.Paragraph
                  ellipsis={{ rows: 3, tooltip: true }}
                  style={{ marginBottom: 0 }}
                >
                  {item.remarkMore}
                </Typography.Paragraph>
              </List.Item>
            )}
          />
        </Space>
      </Card>
    </PageContainer>
  );
};

export default Task;
